@@ -8,6 +8,9 @@
 #include <config.h>
 #include <gnome.h>
 #include <sys/stat.h>
+#include <X11/Xlib.h>
+#include <X11/Xutil.h>
+#include <gdk/gdkx.h>
 #include "gdesktop-icon.h"
 #include "dir.h"
 #include "gdesktop.h"
@@ -91,7 +94,9 @@ size_changed (GnomeIconTextItem *text, gpointer data)
 static void
 canvas_size_allocated (GtkWidget *widget, GtkAllocation *allocation, gpointer data)
 {
-	gnome_canvas_set_scroll_region (GNOME_CANVAS (widget), 0, 0, allocation->width, allocation->height);
+	gnome_canvas_set_scroll_region (GNOME_CANVAS (widget),
+					0, 0,
+					allocation->width, allocation->height);
 }
 
 static void
@@ -102,7 +107,7 @@ desktop_icon_init (DesktopIcon *dicon)
 	/* Set the window policy */
 
 	gtk_window_set_policy (GTK_WINDOW (dicon), TRUE, TRUE, TRUE);
-	gtk_window_set_wmclass (GTK_WINDOW (dicon), "desktop_icon", "gmc");
+
 	/* Create the canvas */
 
 	dicon->canvas = gnome_canvas_new ();
@@ -158,12 +163,6 @@ desktop_icon_realize (GtkWidget *widget)
 	gdk_window_set_decorations (widget->window, 0);
 	gdk_window_set_functions (widget->window, 0);
 
-	/* Remove the client leader property so that the window manager will not
-	 * save SM information for icons.
-	 */
-
-	gdk_property_delete (widget->window, gdk_atom_intern ("WM_CLIENT_LEADER", FALSE));
-
 	/* Set the proper GNOME hints */
 	
 	gnome_win_hints_init ();
@@ -375,8 +374,8 @@ desktop_icon_reshape (DesktopIcon *dicon)
 
 	gnome_canvas_item_get_bounds (dicon->text, &x1, &y1, &x2, &y2);
 
-	text_width = x2 - x1 + 1;
-	text_height = y2 - y1 + 1;
+	text_width = x2 - x1;
+	text_height = y2 - y1;
 
 	/* Calculate new size of widget */
 
@@ -415,6 +414,8 @@ desktop_icon_reshape (DesktopIcon *dicon)
 	dicon->icon_w = icon_width;
 	dicon->icon_h = icon_height;
 
+	gnome_canvas_item_get_bounds (dicon->text, &x1, &y1, &x2, &y2);
+
 	dicon->text_x = x1;
 	dicon->text_y = y1;
 	dicon->text_w = text_width;
