@@ -11,6 +11,7 @@
 #include <stdarg.h>
 #include <string.h>
 #include <ctype.h>
+#include <signal.h>
 #define WANT_WIDGETS		/* bleah */
 #include "tty.h"		/* for KEY_BACKSPACE */
 #include "x.h"
@@ -106,6 +107,8 @@ gmc_color_init (void)
 int
 xtoolkit_init (int *argc, char *argv [])
 {
+	signal (SIGTTIN, SIG_IGN);
+	signal (SIGTTOU, SIG_IGN);
 	gmc_color_init ();
 	return 0;
 }
@@ -415,7 +418,6 @@ x_set_idle (Dlg_head *h, int enable_idle)
 int
 dialog_panel_callback (struct Dlg_head *h, int id, int msg)
 {
-	WInput *in;
 	Widget_Item *dh;
 	void *current_widget;	/* The current widget */
 	
@@ -465,7 +467,7 @@ idle_destroy_panel (gpointer data)
  * when we do not have a CORBA server.
  */
 static void
-non_corba_create_panels (void)
+non_corba_create_panels (char *startup_dir)
 {
 	WPanel *panel;
 
@@ -485,7 +487,7 @@ non_corba_create_panels (void)
 	 * at a higher priority than the one used in session_load().
 	 */
 
-	panel = new_panel_at (".");
+	panel = new_panel_at (startup_dir);
 	gtk_idle_add_priority (GTK_PRIORITY_DEFAULT, idle_destroy_panel, panel);
 	panel->widget.options |= W_PANEL_HIDDEN;
 
@@ -494,21 +496,15 @@ non_corba_create_panels (void)
 	desktop_destroy ();
 }
 
-/*
- * Only at startup we have a strange condition: if more than one
- * panel is created, then the code hangs inside X, it keeps waiting
- * for a reply for something in Imlib that never returns.
- *
- * Creating the panels on the idle loop takes care of this
- */
+/* The GNOME version of create_panels() */
 void
 create_panels (void)
 {
 	if (!corba_have_server)
-		non_corba_create_panels ();
+		non_corba_create_panels (this_dir ? this_dir : ".");
 	else {
 		if (!nowindows)
-			corba_create_window ();
+			corba_create_window (this_dir);
 
 		session_set_restart (FALSE);
 	}
