@@ -32,8 +32,8 @@ void x_add_widget       	     (Dlg_head *h, Widget_Item *w);
 int  translate_gdk_keysym_to_curses (GdkEventKey *event);
 void gnome_init_panels ();
 void bind_gtk_keys (GtkWidget *w, Dlg_head *h);
-WPanel *new_panel_at (char *dir);
-WPanel *new_panel_with_geometry_at (char *dir, char *geometry);
+WPanel *new_panel_at (const char *dir);
+WPanel *new_panel_with_geometry_at (const char *dir, const char *geometry);
 void set_current_panel (WPanel *panel);
 void layout_panel_gone (WPanel *panel);
 void gtkrundlg_event (Dlg_head *h);
