@@ -1322,6 +1322,12 @@ void ftplink_cmd (void)
 	     "[FTP File System]", "/#ftp:", 1);
 }
 
+void smblink_cmd (void)
+{
+    nice_cd (_(" SMB link to machine "), _(machine_str),
+	     "[SMB File System]", "/#smb:", 0);
+}
+
 #ifdef HAVE_SETSOCKOPT
 void source_routing (void)
 {
@@ -1411,8 +1417,6 @@ save_setup_cmd (void)
 void
 configure_panel_listing (WPanel *p, int view_type, int use_msformat, char *user, char *status)
 {
-    int err;
-    
     p->user_mini_status = use_msformat; 
     p->list_type = view_type;
     
@@ -1423,19 +1427,7 @@ configure_panel_listing (WPanel *p, int view_type, int use_msformat, char *user,
 	g_free (p->user_status_format [view_type]);
 	p->user_status_format [view_type] = status;
     
-	err = set_panel_formats (p);
-	
-	if (err){
-	    if (err & 0x01){
-	    	g_free (p->user_format);
-		p->user_format  = g_strdup (DEFAULT_USER_FORMAT);
-	    }
-		
-	    if (err & 0x02){
-		g_free (p->user_status_format [view_type]);
-		p->user_status_format [view_type]  = g_strdup (DEFAULT_USER_FORMAT);
-	    }
-	}
+	set_panel_formats (p);
     }
     else {
         g_free (user);
@@ -1509,6 +1501,8 @@ info_cmd (void)
 void
 quick_view_cmd (void)
 {
+    if (get_panel_widget (MENU_PANEL_IDX) == cpanel)
+	change_panel ();
     set_display_type (MENU_PANEL_IDX, view_quick);
 }
 #endif
