@@ -69,7 +69,7 @@ extern int tree_panel_visible;
 extern int we_can_afford_the_speed;
 #endif
 
-/* "$Id: setup.c,v 1.26 1999/03/27 19:00:18 unammx Exp $" */
+/* "$Id: setup.c,v 1.27 1999/04/06 01:00:34 unammx Exp $" */
 
 #ifdef USE_VFS
 extern int vfs_timeout;
@@ -253,6 +253,9 @@ static struct {
 #endif
 
 #ifdef HAVE_GNOME
+    { "desktop_use_shaped_icons", &desktop_use_shaped_icons },
+    { "desktop_auto_placement", &desktop_auto_placement },
+    { "desktop_snap_icons", &desktop_snap_icons },
     { "tree_panel_visible", &tree_panel_visible },
     { "we_can_afford_the_speed", &we_can_afford_the_speed },
 #else
