@@ -76,7 +76,7 @@
 #include "user.h"		/* expand_format */
 #include "../vfs/vfs.h"
 
-/* "$Id: util.c,v 1.26 1999/04/30 12:41:42 unammx Exp $" */
+/* "$Id: util.c,v 1.27 1999/06/01 22:39:14 unammx Exp $" */
 
 char app_text [] = "Midnight-Commander";
 
@@ -104,6 +104,10 @@ int is_printable (int c)
     extern int eight_bit_clean;
     extern int full_eight_bits;
 
+#ifdef HAVE_GNOME
+    return 1;
+#endif
+    
     c &= 0xff;
     if (eight_bit_clean){
         if (full_eight_bits){
